from setuptools import setup

setup(
    name='tgb',
    version='1.1.0',
    description='A minimal Telegram API wrappper',
    url='https://github.com/banteg/telegram',
    py_modules=['telegram'],
    install_requires=['requests'],
)
